@@ -593,7 +593,7 @@ mod tests {
 
         for path in paths {
             let device_path = DevicePath::new(path).expect("our test path");
-            let info = block_device_apply(&device_path, |dev| process_stratis_device(dev))
+            let info = block_device_apply(&device_path, process_stratis_device)
                 .unwrap()
                 .unwrap()
                 .unwrap();
@@ -601,7 +601,7 @@ mod tests {
             assert_eq!(&&info.devnode, path);
 
             assert_eq!(
-                block_device_apply(&device_path, |dev| process_luks_device(dev))
+                block_device_apply(&device_path, process_luks_device)
                     .unwrap()
                     .unwrap(),
                 None
@@ -639,13 +639,13 @@ mod tests {
         for path in paths {
             let device_path = DevicePath::new(path).expect("our test path");
             assert_eq!(
-                block_device_apply(&device_path, |dev| process_stratis_device(dev))
+                block_device_apply(&device_path, process_stratis_device)
                     .unwrap()
                     .unwrap(),
                 None
             );
             assert_eq!(
-                block_device_apply(&device_path, |dev| process_luks_device(dev))
+                block_device_apply(&device_path, process_luks_device)
                     .unwrap()
                     .unwrap(),
                 None
@@ -656,13 +656,13 @@ mod tests {
             create_fs(path, None, false).unwrap();
             let device_path = DevicePath::new(path).expect("our test path");
             assert_eq!(
-                block_device_apply(&device_path, |dev| process_stratis_device(dev))
+                block_device_apply(&device_path, process_stratis_device)
                     .unwrap()
                     .unwrap(),
                 None
             );
             assert_eq!(
-                block_device_apply(&device_path, |dev| process_luks_device(dev))
+                block_device_apply(&device_path, process_luks_device)
                     .unwrap()
                     .unwrap(),
                 None
