@@ -136,6 +136,7 @@ fn check_metadata(metadata: &PoolSave) -> StratisResult<()> {
 #[derive(Debug)]
 pub struct StratPool {
     backstore: Backstore,
+    #[allow(dead_code)]
     redundancy: Redundancy,
     thin_pool: ThinPool,
     action_avail: ActionAvailability,
@@ -392,6 +393,13 @@ impl<'a> Into<Value> for &'a StratPool {
     }
 }
 
+pub fn total_physical_used(
+    backstore: &Backstore,
+    size: StratisResult<Sectors>,
+) -> StratisResult<Sectors> {
+    size.map(|v| v + backstore.datatier_metadata_size())
+}
+
 #[strat_pool_impl_gen]
 impl Pool for StratPool {
     type Filesystem = StratFilesystem;
@@ -677,9 +685,7 @@ impl Pool for StratPool {
         // by the pool abstraction will be invalid. In the event of, e.g.,
         // software RAID, the amount will be far too low to be useful, in the
         // event of, e.g, VDO, the amount will be far too large to be useful.
-        self.thin_pool
-            .total_physical_used()
-            .map(|v| v + self.backstore.datatier_metadata_size())
+        total_physical_used(&self.backstore, self.thin_pool.total_physical_used())
     }
 
     fn filesystems(&self) -> Vec<(Name, FilesystemUuid, &Self::Filesystem)> {
